pub enum Module {
Empty,
Masked(Color),
Unmasked(Color),
}Expand description
The color of a module (pixel) in the QR code.
Variants
Empty
The module is empty.
Masked(Color)
The module is of functional patterns which cannot be masked, or pixels which have been masked.
Unmasked(Color)
The module is of data and error correction bits before masking.
Implementations
Sourceimpl Module
impl Module
Sourcepub fn mask(self, should_invert: bool) -> Module
pub fn mask(self, should_invert: bool) -> Module
Apply a mask to the unmasked modules.
use qrcode_core::canvas::Module;
use qrcode_core::types::Color;
assert_eq!(Module::Unmasked(Color::Light).mask(true), Module::Masked(Color::Dark));
assert_eq!(Module::Unmasked(Color::Dark).mask(true), Module::Masked(Color::Light));
assert_eq!(Module::Unmasked(Color::Light).mask(false), Module::Masked(Color::Light));
assert_eq!(Module::Masked(Color::Dark).mask(true), Module::Masked(Color::Dark));
assert_eq!(Module::Masked(Color::Dark).mask(false), Module::Masked(Color::Dark));Trait Implementations
impl Copy for Module
impl Eq for Module
impl StructuralPartialEq for Module