QrError

Enum QrError 

#[non_exhaustive]
pub enum QrError { DataTooLong, InvalidVersion { version: Version, ec_level: EcLevel, }, UnsupportedCharacterSet, InvalidEciDesignator { value: u32, }, InvalidCharacter { position: usize, byte: u8, }, }
QrError encodes the error encountered when generating a QR code.

This enum is #[non_exhaustive]: future versions may add variants, so external callers should match with a _ arm.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


DataTooLong

The data is too long to encode into a QR code for the given version.



InvalidVersion

The provided version / error correction level combination is invalid. Carries the offending Version and EcLevel.

Fields

version: Version
ec_level: EcLevel


UnsupportedCharacterSet

Some characters in the data cannot be supported by the provided QR code version.



InvalidEciDesignator

The provided ECI designator is invalid. Carries the offending value; a valid designator must be between 0 and 999999.

Fields

value: u32


InvalidCharacter

A character not belonging to the character set is found. Carries the byte position (offset into the input) and the offending byte value.

Fields

position: usize
byte: u8